#

##

##

###

###

##

###

###

    	saves

    	format
    		__saves
    			dumps
    			exports

    	exports and imports
    		export
    			mongoexport --uri "mongodb://0.0.0.0:39000/ingredients" --collection "essential_nutrients" --out "_exports/ingredients/essential_nutrients/1.JSON"

    			mongoexport --uri "mongodb://0.0.0.0:39000/ingredients" --collection "cautionary_ingredients" --out "_exports/ingredients/cautionary_ingredients/1.JSON"

    			chmod -R 777 _exports

    		import

    	dump and restore
    		dump

    		restore